import * as React from 'react';
import * as ReactNative from 'react-native';
export declare type BaseFieldValue = any;
export declare type FieldValues = Record<string, BaseFieldValue>;
export declare type RawFieldName<FormValues extends FieldValues> = Extract<keyof FormValues, string>;
export declare type FieldName<FormValues extends FieldValues> = RawFieldName<FormValues> | string;
export declare type FieldValue<FormValues extends FieldValues> = FormValues[FieldName<FormValues>];
export declare type Ref = any;
declare type Mode = keyof ValidationMode;
export declare type OnSubmit<FormValues extends FieldValues> = (data: FormValues, e: React.SyntheticEvent | ReactNative.GestureResponderEvent) => void | Promise<void>;
export interface ValidationMode {
    onBlur: 'onBlur';
    onChange: 'onChange';
    onSubmit: 'onSubmit';
}
export declare type SchemaValidateOptions = Partial<{
    strict: boolean;
    abortEarly: boolean;
    stripUnknown: boolean;
    recursive: boolean;
    context: object;
}>;
export interface Schema<Data> {
    validate(value: FieldValues, options?: SchemaValidateOptions): Promise<Data>;
}
export declare type Options<FormValues extends FieldValues = FieldValues> = Partial<{
    mode: Mode;
    defaultValues: Partial<FormValues>;
    validationSchemaOption: SchemaValidateOptions;
    validationFields: FieldName<FormValues>[];
    validationSchema: any;
    nativeValidation: boolean;
    submitFocusError: boolean;
}>;
export interface MutationWatcher {
    disconnect: VoidFunction;
    observe?: any;
}
declare type ValidationOptionObject<Value> = Value | {
    value: Value;
    message: string;
};
export declare type ValidationTypes = number | string | RegExp;
export declare type ValidateResult = string | boolean | void;
export declare type Validate = (data: BaseFieldValue) => ValidateResult;
export declare type ValidationOptions = Partial<{
    required: boolean | string;
    min: ValidationOptionObject<number | string>;
    max: ValidationOptionObject<number | string>;
    maxLength: ValidationOptionObject<number | string>;
    minLength: ValidationOptionObject<number | string>;
    pattern: ValidationOptionObject<RegExp>;
    validate: Validate | Record<string, Validate> | {
        value: Validate | Record<string, Validate>;
        message: string;
    };
}>;
export interface FieldError {
    ref: Ref;
    type: string;
    message?: string;
    isManual?: boolean;
}
export declare type ValidatePromiseResult = {} | void | FieldError;
export interface Field extends ValidationOptions {
    ref: Ref;
    watch?: boolean;
    mutationWatcher?: MutationWatcher;
    options?: {
        ref: Ref;
        mutationWatcher?: MutationWatcher;
    }[];
}
export declare type FieldsRefs<Data extends FieldValues> = Partial<Record<FieldName<Data>, Field>>;
export declare type FieldErrors<Data extends FieldValues> = Partial<Record<FieldName<Data>, FieldError>>;
export interface SubmitPromiseResult<Data extends FieldValues> {
    errors: FieldErrors<Data>;
    values: Data;
}
export interface SchemaValidationResult<FormValues> {
    fieldErrors: FieldErrors<FormValues>;
    result: FieldValues;
}
export interface ValidationPayload<Name, Value> {
    name: Name;
    value?: Value;
}
export interface FormState<FormValues extends FieldValues = FieldValues> {
    dirty: boolean;
    isSubmitted: boolean;
    submitCount: number;
    touched: FieldName<FormValues>[];
    isSubmitting: boolean;
    isValid: boolean;
}
export interface ElementLike {
    name: string;
    type?: string;
    value?: string;
    checked?: boolean;
    options?: any;
}
export {};
